==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentit",
    "Unknown user" : "Tuntematon käyttäjä",
    "New comment …" : "Uusi kommentti…",
    "Delete comment" : "Poista kommentti",
    "Post" : "Lähetä",
    "Cancel" : "Peruuta",
    "Edit comment" : "Muokkaa kommenttia",
    "[Deleted user]" : "[Poistettu käyttäjä]",
    "No comments yet, start the conversation!" : "Ei kommentteja vielä. Aloita keskustelu!",
    "More comments …" : "Lisää kommentteja…",
    "Save" : "Tallenna",
    "Allowed characters {count} of {max}" : "Sallittujen merkkien määrä {count}/{max}",
    "Error occurred while retrieving comment with id {id}" : "Virhe noutaessa kommenttia tunnisteella {id}",
    "Error occurred while updating comment with id {id}" : "Virhe päivittäessä kommenttia tunnisteella {id}",
    "Error occurred while posting comment" : "Virhe kommenttia lähettäessä",
    "_%n unread comment_::_%n unread comments_" : ["%n lukematon kommentti","%n lukematonta kommenttia"],
    "Comment" : "Kommentti",
    "You commented" : "Kommentoit",
    "%1$s commented" : "%1$s kommentoi",
    "{author} commented" : "{author} kommentoi",
    "You commented on %1$s" : "Kommentoit %1$s",
    "You commented on {file}" : "Kommentoit tiedostoa {file}",
    "%1$s commented on %2$s" : "%1$s kommentoi kohdetta %2$s",
    "{author} commented on {file}" : "{author} kommentoi tiedostoa {file}",
    "<strong>Comments</strong> for files" : "Tiedostojen <strong>kommentit</strong>",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Poistettu käyttäjä mainitsi sinut kommentissa \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Poistettu käyttäjä mainitsi sinut tiedoston \"{file}\" kommentissa",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mainitsi sinut kommentissa “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainitsi sinut tiedoston \"{file}\" kommentissa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentit",
    "Unknown user" : "Tuntematon käyttäjä",
    "New comment …" : "Uusi kommentti…",
    "Delete comment" : "Poista kommentti",
    "Post" : "Lähetä",
    "Cancel" : "Peruuta",
    "Edit comment" : "Muokkaa kommenttia",
    "[Deleted user]" : "[Poistettu käyttäjä]",
    "No comments yet, start the conversation!" : "Ei kommentteja vielä. Aloita keskustelu!",
    "More comments …" : "Lisää kommentteja…",
    "Save" : "Tallenna",
    "Allowed characters {count} of {max}" : "Sallittujen merkkien määrä {count}/{max}",
    "Error occurred while retrieving comment with id {id}" : "Virhe noutaessa kommenttia tunnisteella {id}",
    "Error occurred while updating comment with id {id}" : "Virhe päivittäessä kommenttia tunnisteella {id}",
    "Error occurred while posting comment" : "Virhe kommenttia lähettäessä",
    "_%n unread comment_::_%n unread comments_" : ["%n lukematon kommentti","%n lukematonta kommenttia"],
    "Comment" : "Kommentti",
    "You commented" : "Kommentoit",
    "%1$s commented" : "%1$s kommentoi",
    "{author} commented" : "{author} kommentoi",
    "You commented on %1$s" : "Kommentoit %1$s",
    "You commented on {file}" : "Kommentoit tiedostoa {file}",
    "%1$s commented on %2$s" : "%1$s kommentoi kohdetta %2$s",
    "{author} commented on {file}" : "{author} kommentoi tiedostoa {file}",
    "<strong>Comments</strong> for files" : "Tiedostojen <strong>kommentit</strong>",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mainitsi sinut kommentissa “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainitsi sinut tiedoston \"{file}\" kommentissa",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Poistettu käyttäjä mainitsi sinut kommentissa \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Poistettu käyttäjä mainitsi sinut tiedoston \"{file}\" kommentissa"
},
"nplurals=2; plural=(n != 1);");
